@@ -1,16 +1,15 @@
 import numpy as np
 import time
-
+from tqdm import trange
 from dec_opt.gossip_matrix import GossipMatrix
 from dec_opt.compression import Compression
+from time import sleep
 
 """
 Author: Anish Acharya
 Contact: anishacharya@utexas.edu
 """
 
-np.random.seed(1)
-
 
 class DecGD:
     def __init__(self, data_reader, hyper_param, model):
@@ -34,6 +33,7 @@ class DecGD:
         self.num_samples, self.num_features = self.A_train.shape
         INIT_WEIGHT_STD = 1 / np.sqrt(self.num_features)
 
+        np.random.seed(self.param.seed)
         self.model.x_estimate = np.random.normal(0, INIT_WEIGHT_STD, size=(self.num_features, self.param.n_cores))
         # self.model.x_estimate = np.tile(self.model.x_estimate, (self.param.n_cores, 1)).T
 
@@ -69,7 +69,9 @@ class DecGD:
         train_losses[0] = self.model.loss(self.A_train, self.y_train)
         test_losses[0] = self.model.loss(self.A_test, self.y_test)
         train_start = time.time()
-        for epoch in np.arange(self.param.epochs):
+        t = trange(self.param.epochs, leave=True, position=0)
+        # for epoch in np.arange(self.param.epochs):
+        for epoch in t:
             loss = self.model.loss(self.A_train, self.y_train)
             if np.isinf(loss) or np.isnan(loss):
                 print("training exit - diverging")
@@ -142,8 +144,11 @@ class DecGD:
 
             train_acc = compute_accuracy(model=self.model, feature=self.A_train, target=self.y_train)
             test_acc = compute_accuracy(model=self.model, feature=self.A_test, target=self.y_test)
-            print("epoch : {}; loss: {}; Train accuracy : {}".format(epoch, train_losses[epoch + 1], train_acc))
-            print("epoch : {}; loss: {}; Test accuracy : {}".format(epoch, test_losses[epoch + 1], test_acc))
+            t.set_description("epoch : {}; Train loss: {}; Train accuracy : {}, Test Accuracy : {} ".
+                              format(epoch, train_losses[epoch + 1], train_acc, test_acc))
+            sleep(0.1)
+            # print("epoch : {}; loss: {}; Train accuracy : {}".format(epoch, train_losses[epoch + 1], train_acc))
+            # print("epoch : {}; loss: {}; Test accuracy : {}".format(epoch, test_losses[epoch + 1], test_acc))
             if np.isinf(train_losses[epoch + 1]) or np.isnan(train_losses[epoch + 1]):
                 print("Break training - Diverged")
                 break
